@@ -1,8 +1,8 @@
-import vatnumber
 from decimal import Decimal
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
+from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.core.validators import EMPTY_VALUES
+from internationalflavor.vat_number import VATNumberValidator
 
 from invoicing.taxation import TaxationPolicy
 
@@ -58,6 +58,9 @@ class EUTaxationPolicy(TaxationPolicy):
 
     @classmethod
     def is_in_EU(cls, country_code):
+        if country_code == 'GB':
+            return False
+
         return country_code.upper() in cls.EU_COUNTRIES_RATES.keys()
 
     @classmethod
@@ -109,24 +112,25 @@ class EUTaxationPolicy(TaxationPolicy):
             # Normal tax
             return cls.get_default_tax(supplier_country)
 
-        if cls.is_in_EU(customer_country):
-            # Company is from other EU country
-            try:
-                use_vies_validator = getattr(settings, 'INVOICING_USE_VIES_VALIDATOR', True)
-                vies_valid = vatnumber.check_vies(vat_id) if use_vies_validator else True
-
-                if vat_id and vies_valid:
-                    # Company is registered in VIES
-                    # Charge back
-                    return None
-                else:
-                    return cls.get_default_tax(supplier_country)
-            except ImportError as e:
-                raise e
-            except Exception as e:
-                # If we could not connect to VIES
-                return cls.get_default_tax(supplier_country)
-        else:
+        if not cls.is_in_EU(customer_country):
             # Company is not from EU
             # Charge back
             return None
+
+        # Company is from other EU country
+        use_vies_validator = getattr(settings, 'INVOICING_USE_VIES_VALIDATOR', True)
+
+        if not use_vies_validator:
+            # trust VAT ID is correct
+            # Charge back
+            return None
+
+        try:
+            # verify VAT ID in VIES
+            VATNumberValidator(eu_only=True, vies_check=True)(vat_id)
+
+            # Company is registered in VIES
+            # Charge back
+            return None
+        except ValidationError:
+            return cls.get_default_tax(supplier_country)
